.. _${namespace-lower}-${msl-package-lower}-welcome:

${namespace}-${msl-package}
${=}

Write the documentation for **${namespace}-${msl-package}**.

Contents
========

.. toctree::
   :maxdepth: 2

   License <license>
   Authors <authors>
   Release Notes <changelog>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
